@@ -4,6 +4,7 @@ try:
   import board
 except NotImplementedError as exc:
   print(f"Note: This machine is not compatible with MLX90640")
+  raise NotImplementedError from exc
 else:
   import busio
   import adafruit_mlx90640
@@ -23,7 +24,7 @@ def main():
   except ImportError as exc:
     print("Error: Could not import Process_raw, not started main loop")
   while True:
-    process.iterate(process.print_frame_value)
+    print(get_frame())
 
 def get_frame():
   frame = [0] * (24*32)
