@@ -1,7 +1,17 @@
+from __future__ import annotations
 import json
-from typing import Callable, Tuple, Type, TypeVar
-from .lib.AIO import aio
-from .lib.ThermalSensor.Extract_raw import get_frame
+from random import randrange
+import sys
+from typing import Callable, List, Tuple, Type, TypeVar
+
+from ahIOT.firebase import send_firebase
+try:
+  from .lib.AIO import aio
+  from .lib.ThermalSensor.Extract_raw import get_frame
+except NotImplementedError:
+  print("Not implemented for this platform :(")
+
+_isFirebase = False
 
 T_Data = TypeVar('T_Data')
 def _step(
@@ -23,7 +33,6 @@ def _method():
 
 def _send(data):
   # print(f"[Debug: pi.py] Sending data: {data=}")
-  
   try:
     aio.send_stream_data(data)
     return True
@@ -33,16 +42,25 @@ def _send(data):
     return False
 
 def step():
-  aio.pi_ping()
   # Step for uploading data
-  _step(
-    method = _method,
-    callback = _send,
-  )
-  # Other steps could be added below, such as 8x8 LED matrix
+  if not _isFirebase:
+    aio.pi_ping()
+    _step(
+      method = _method,
+      callback = _send,
+    )
+  else:
+    if _isFirebase: _step(
+      method = _method,
+      callback = send_firebase,
+    )
 
 def main():
   print("Beginning pi ...")
+  if sys.argv[1] == "firebase":
+    global _isFirebase
+    _isFirebase = True
+    print("Using firebase!")
   while True: 
     step()
 
